@@ -30,9 +30,15 @@ typedef enum
   BABL_CPU_ACCEL_X86_SSE     = 0x10000000,
   BABL_CPU_ACCEL_X86_SSE2    = 0x08000000,
   BABL_CPU_ACCEL_X86_SSE3    = 0x02000000,
+  BABL_CPU_ACCEL_X86_SSSE3   = 0x00800000,
+  BABL_CPU_ACCEL_X86_SSE4_1  = 0x00400000,
+  /* BABL_CPU_ACCEL_X86_SSE4_2  = 0x00200000, */
+  /* BABL_CPU_ACCEL_X86_AVX     = 0x00080000, */
+  BABL_CPU_ACCEL_X86_F16C    = 0x00040000,
 
   /* powerpc accelerations */
-  BABL_CPU_ACCEL_PPC_ALTIVEC = 0x04000000
+  BABL_CPU_ACCEL_PPC_ALTIVEC = 0x04000000,
+  BABL_CPU_ACCEL_X86_64      = 0x00100000
 } BablCpuAccelFlags;
 
 
