@@ -52,12 +52,6 @@
 #include "babl-mutex.h"
 #include "babl-cpuaccel.h"
 
-/* redefining some functions for the win32 platform */
-#ifdef _WIN32
-#define srandom srand
-#define random  rand
-#endif
-
 /* fallback to floor function when rint is not around */
 #ifndef HAVE_RINT
 # define rint(f)  (floor (((double) (f)) + 0.5))
@@ -82,10 +76,10 @@ void     babl_set_extender              (Babl           *new_extender);
 Babl   * babl_extension_quiet_log       (void);
 void     babl_extension_deinit          (void);
 
-long     babl_fish_reference_process    (const Babl     *babl,
-                                         const BablImage*source,
-                                         BablImage      *destination,
-                                         long            n);
+long     babl_fish_reference_process    (const Babl *babl,
+                                         const char *source,
+                                         char       *destination,
+                                         long        n);
 
 Babl   * babl_fish_reference            (const Babl     *source,
                                          const Babl     *destination);
@@ -118,14 +112,13 @@ int      babl_type_is_symmetric         (const Babl     *babl);
 int babl_backtrack (void);
 
 static inline void
-real_babl_log (const char *file,
-               int         line,
-               const char *function,
-               const char *fmt, ...)
+real_babl_log_va(const char *file,
+                 int         line,
+                 const char *function,
+                 const char *fmt,
+                 va_list     varg)
 {
   Babl *extender = babl_extender();
-  va_list  varg;
-
 
   if (extender != babl_extension_quiet_log())
     {
@@ -135,15 +128,26 @@ real_babl_log (const char *file,
       fprintf (stdout, "%s:%i %s()\n\t", file, line, function);
     }
 
-  va_start (varg, fmt);
   vfprintf (stdout, fmt, varg);
-  va_end (varg);
 
   fprintf (stdout, "\n");
   fflush (NULL);
   return;
 }
 
+static inline void
+real_babl_log (const char *file,
+               int         line,
+               const char *function,
+               const char *fmt, ...)
+{
+  va_list  varg;
+
+  va_start (varg, fmt);
+  real_babl_log_va(file, line, function, fmt, varg);
+  va_end (varg);
+}
+
 /* Provide a string identifying the current function, non-concatenatable */
 #ifndef G_STRFUNC
 #if defined (__GNUC__)
@@ -186,7 +190,7 @@ babl_log (const char *format, ...)
 {
   va_list args;
   va_start (args, format);
-  real_babl_log (__FILE__, __LINE__, G_STRFUNC, format, args);
+  real_babl_log_va (__FILE__, __LINE__, G_STRFUNC, format, args);
   va_end (args);
 }
 static inline void
@@ -194,7 +198,7 @@ babl_fatal (const char *format, ...)
 {
   va_list args;
   va_start (args, format);
-  real_babl_log (__FILE__, __LINE__, G_STRFUNC, format, args);
+  real_babl_log_va (__FILE__, __LINE__, G_STRFUNC, format, args);
   va_end (args);
   babl_die();
 }
@@ -291,4 +295,26 @@ babl_##klass##_from_id (int id)                               \
 
 #define BABL(obj)  ((Babl*)(obj))
 
+static inline double babl_parse_double (const char *str)
+{
+  double result = 0;
+  if (!str)
+    return 0.0;
+  result = atoi (str);
+  if (strchr (str, '.'))
+  {
+    char *p = strchr (str, '.') + 1;
+    double d = 10;
+    for (;*p && *p >= '0' && *p <= '9';p++, d *= 10)
+    {
+      if (result >= 0)
+        result += (*p - '0') / d;
+      else
+        result -= (*p - '0') / d;
+    }
+  }
+  return result;
+}
+
+
 #endif
