@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <string.h>
 #include <stdint.h>
 #include <assert.h>
@@ -106,7 +107,7 @@ convert_u32_double_scaled (double   min_val,
                                       src, dst, src_pitch, dst_pitch, n); \
   }
 
-MAKE_CONVERSIONS (u32, 0.0, 1.0, 0, UINT32_MAX);
+MAKE_CONVERSIONS (u32, 0.0, 1.0, 0, UINT32_MAX)
 
 void
 babl_base_type_u32 (void)
@@ -118,15 +119,15 @@ babl_base_type_u32 (void)
     NULL);
 
   babl_conversion_new (
-    babl_type_id (BABL_U32),
-    babl_type_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_U32),
+    babl_type_from_id (BABL_DOUBLE),
     "plane", convert_u32_double,
     NULL
   );
 
   babl_conversion_new (
-    babl_type_id (BABL_DOUBLE),
-    babl_type_id (BABL_U32),
+    babl_type_from_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_U32),
     "plane", convert_double_u32,
     NULL
   );
