@@ -28,6 +28,29 @@
 #define DEGREES_PER_RADIAN (180 / 3.14159265358979323846)
 #define RADIANS_PER_DEGREE (1 / DEGREES_PER_RADIAN)
 
+#define LAB_EPSILON       (216.0 / 24389.0)
+#define LAB_KAPPA         (24389.0 / 27.0)
+
+/* The constants below hard-code the D50-adapted sRGB ICC profile
+ * reference white, aka the ICC profile D50 illuminant.
+ *
+ * In a properly ICC profile color-managed application, the profile
+ * illuminant values should be retrieved from the image's
+ * ICC profile's illuminant.
+ *
+ * At present, the ICC profile illuminant is always D50. This might
+ * change when the next version of the ICC specs is released.
+ *
+ * As encoded in an actual V2 or V4 ICC profile,
+ * the illuminant values are hexadecimal-rounded, as are the following
+ * hard-coded D50 ICC profile illuminant values:
+ */
+
+#define D50_WHITE_REF_X   0.964202880
+#define D50_WHITE_REF_Y   1.000000000
+#define D50_WHITE_REF_Z   0.824905400
+
+
 int init (void);
 
 static void types (void);
@@ -415,6 +438,183 @@ lchaba_to_rgba (char *src,
   return n;
 }
 
+static inline float
+cubef (float f)
+{
+  return f * f * f;
+}
+
+static long
+Yaf_to_Laf (float *src,
+            float *dst,
+            long   samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      float yr = src[0];
+      float a  = src[1];
+      float L  = yr > LAB_EPSILON ? 116.0 * cbrtf (yr) - 16 : LAB_KAPPA * yr;
+
+      dst[0] = L;
+      dst[1] = a;
+
+      src += 2;
+      dst += 2;
+    }
+
+  return samples;
+}
+
+static long
+rgbf_to_Labf (float *src,
+              float *dst,
+              long   samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      float r = src[0];
+      float g = src[1];
+      float b = src[2];
+
+      float xr = 0.43603516f / D50_WHITE_REF_X * r + 0.38511658f / D50_WHITE_REF_X * g + 0.14305115f / D50_WHITE_REF_X * b;
+      float yr = 0.22248840f / D50_WHITE_REF_Y * r + 0.71690369f / D50_WHITE_REF_Y * g + 0.06060791f / D50_WHITE_REF_Y * b;
+      float zr = 0.01391602f / D50_WHITE_REF_Z * r + 0.09706116f / D50_WHITE_REF_Z * g + 0.71392822f / D50_WHITE_REF_Z * b;
+
+      float fx = xr > LAB_EPSILON ? cbrtf (xr) : (LAB_KAPPA * xr + 16.0f) / 116.0f;
+      float fy = yr > LAB_EPSILON ? cbrtf (yr) : (LAB_KAPPA * yr + 16.0f) / 116.0f;
+      float fz = zr > LAB_EPSILON ? cbrtf (zr) : (LAB_KAPPA * zr + 16.0f) / 116.0f;
+
+      float L = 116.0f * fy - 16.0f;
+      float A = 500.0f * (fx - fy);
+      float B = 200.0f * (fy - fz);
+
+      dst[0] = L;
+      dst[1] = A;
+      dst[2] = B;
+
+      src += 3;
+      dst += 3;
+    }
+
+  return samples;
+}
+
+static long
+rgbaf_to_Labaf (float *src,
+                float *dst,
+                long   samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      float r = src[0];
+      float g = src[1];
+      float b = src[2];
+      float a = src[3];
+
+      float xr = 0.43603516f / D50_WHITE_REF_X * r + 0.38511658f / D50_WHITE_REF_X * g + 0.14305115f / D50_WHITE_REF_X * b;
+      float yr = 0.22248840f / D50_WHITE_REF_Y * r + 0.71690369f / D50_WHITE_REF_Y * g + 0.06060791f / D50_WHITE_REF_Y * b;
+      float zr = 0.01391602f / D50_WHITE_REF_Z * r + 0.09706116f / D50_WHITE_REF_Z * g + 0.71392822f / D50_WHITE_REF_Z * b;
+
+      float fx = xr > LAB_EPSILON ? cbrtf (xr) : (LAB_KAPPA * xr + 16.0f) / 116.0f;
+      float fy = yr > LAB_EPSILON ? cbrtf (yr) : (LAB_KAPPA * yr + 16.0f) / 116.0f;
+      float fz = zr > LAB_EPSILON ? cbrtf (zr) : (LAB_KAPPA * zr + 16.0f) / 116.0f;
+
+      float L = 116.0f * fy - 16.0f;
+      float A = 500.0f * (fx - fy);
+      float B = 200.0f * (fy - fz);
+
+      dst[0] = L;
+      dst[1] = A;
+      dst[2] = B;
+      dst[3] = a;
+
+      src += 4;
+      dst += 4;
+    }
+
+  return samples;
+}
+
+static long
+Labf_to_rgbf (float *src,
+                float *dst,
+                long   samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      float L = src[0];
+      float A = src[1];
+      float B = src[2];
+
+      float fy = (L + 16.0f) / 116.0f;
+      float fx = fy + A / 500.0f;
+      float fz = fy - B / 200.0f;
+
+      float yr = L > LAB_KAPPA * LAB_EPSILON ? cubef (fy) : L / LAB_KAPPA;
+      float xr = cubef (fx) > LAB_EPSILON ? cubef (fx) : (fx * 116.0f - 16.0f) / LAB_KAPPA;
+      float zr = cubef (fz) > LAB_EPSILON ? cubef (fz) : (fz * 116.0f - 16.0f) / LAB_KAPPA;
+
+      float r =  3.134274799724f * D50_WHITE_REF_X * xr -1.617275708956f * D50_WHITE_REF_Y * yr -0.490724283042f * D50_WHITE_REF_Z * zr;
+      float g = -0.978795575994f * D50_WHITE_REF_X * xr +1.916161689117f * D50_WHITE_REF_Y * yr +0.033453331711f * D50_WHITE_REF_Z * zr;
+      float b =  0.071976988401f * D50_WHITE_REF_X * xr -0.228984974402f * D50_WHITE_REF_Y * yr +1.405718224383f * D50_WHITE_REF_Z * zr;
+
+      dst[0] = r;
+      dst[1] = g;
+      dst[2] = b;
+
+      src += 3;
+      dst += 3;
+    }
+
+  return samples;
+}
+
+static long
+Labaf_to_rgbaf (float *src,
+                float *dst,
+                long   samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      float L = src[0];
+      float A = src[1];
+      float B = src[2];
+      float a = src[3];
+
+      float fy = (L + 16.0f) / 116.0f;
+      float fx = fy + A / 500.0f;
+      float fz = fy - B / 200.0f;
+
+      float yr = L > LAB_KAPPA * LAB_EPSILON ? cubef (fy) : L / LAB_KAPPA;
+      float xr = cubef (fx) > LAB_EPSILON ? cubef (fx) : (fx * 116.0f - 16.0f) / LAB_KAPPA;
+      float zr = cubef (fz) > LAB_EPSILON ? cubef (fz) : (fz * 116.0f - 16.0f) / LAB_KAPPA;
+
+      float r =  3.134274799724f * D50_WHITE_REF_X * xr -1.617275708956f * D50_WHITE_REF_Y * yr -0.490724283042f * D50_WHITE_REF_Z * zr;
+      float g = -0.978795575994f * D50_WHITE_REF_X * xr +1.916161689117f * D50_WHITE_REF_Y * yr +0.033453331711f * D50_WHITE_REF_Z * zr;
+      float b =  0.071976988401f * D50_WHITE_REF_X * xr -0.228984974402f * D50_WHITE_REF_Y * yr +1.405718224383f * D50_WHITE_REF_Z * zr;
+
+      dst[0] = r;
+      dst[1] = g;
+      dst[2] = b;
+      dst[3] = a;
+
+      src += 4;
+      dst += 4;
+    }
+
+  return samples;
+}
+
 static void
 conversions (void)
 {
@@ -442,7 +642,36 @@ conversions (void)
     "linear", laba_to_rgba,
     NULL
   );
-
+  babl_conversion_new (
+    babl_format ("RGB float"),
+    babl_format ("CIE Lab float"),
+    "linear", rgbf_to_Labf,
+    NULL
+  );
+  babl_conversion_new (
+    babl_format ("CIE Lab float"),
+    babl_format ("RGB float"),
+    "linear", Labf_to_rgbf,
+    NULL
+  );
+  babl_conversion_new (
+    babl_format ("RGBA float"),
+    babl_format ("CIE Lab alpha float"),
+    "linear", rgbaf_to_Labaf,
+    NULL
+  );
+  babl_conversion_new (
+    babl_format ("CIE Lab alpha float"),
+    babl_format ("RGBA float"),
+    "linear", Labaf_to_rgbaf,
+    NULL
+  );
+  babl_conversion_new (
+    babl_format ("YA float"),
+    babl_format ("CIE L alpha float"),
+    "linear", Yaf_to_Laf,
+    NULL
+  );
   babl_conversion_new (
     babl_model ("RGBA"),
     babl_model ("CIE LCH(ab)"),
@@ -517,6 +746,14 @@ formats (void)
     babl_component ("A"),
     NULL);
 
+  babl_format_new (
+    "name", "CIE L alpha float",
+    babl_model ("CIE Lab alpha"),
+    babl_type ("float"),
+    babl_component ("CIE L"),
+    babl_component ("A"),
+    NULL);
+
   babl_format_new (
     "name", "CIE Lab u8",
     babl_model ("CIE Lab"),
@@ -934,44 +1171,20 @@ XYZ_to_LAB (double X,
             double *to_a,
             double *to_b)
 {
-
-  const double kappa   = 903.3;//24389.0/27.0;
-  const double epsilon = 0.008856;//216/24389.0;
-  
-/* The constants below hard-code the D50-adapted sRGB ICC profile 
- * reference white, aka the ICC profile D50 illuminant. 
- * 
- * In a properly ICC profile color-managed application, the profile 
- * illuminant values should be retrieved from the image's
- * ICC profile's illuminant.
- * 
- * At present, the ICC profile illuminant is always D50. This might
- * change when the next version of the ICC specs is released.
- * 
- * As encoded in an actual V2 or V4 ICC profile, 
- * the illuminant values are hexadecimal-rounded, as are the following 
- * hard-coded D50 ICC profile illuminant values:
- * 
- * */  
-  const double X_reference_white = 0.964202880;
-  const double Y_reference_white = 1.000000000;
-  const double Z_reference_white = 0.824905400;
- 
-  double x_r = X/X_reference_white;
-  double y_r = Y/Y_reference_white;
-  double z_r = Z/Z_reference_white;
-  
   double f_x, f_y, f_z;
   
-  if (x_r > epsilon) f_x = pow(x_r, 1.0 / 3.0);
-  else ( f_x = ((kappa * x_r) + 16) / 116.0 );
-  
-  if (y_r > epsilon) f_y = pow(y_r, 1.0 / 3.0);
-  else ( f_y = ((kappa * y_r) + 16) / 116.0 );
-  
-  if (z_r > epsilon) f_z = pow(z_r, 1.0 / 3.0);
-  else ( f_z = ((kappa * z_r) + 16) / 116.0 );
+  double x_r = X / D50_WHITE_REF_X;
+  double y_r = Y / D50_WHITE_REF_Y;
+  double z_r = Z / D50_WHITE_REF_Z;
 
+  if (x_r > LAB_EPSILON) f_x = pow(x_r, 1.0 / 3.0);
+  else ( f_x = ((LAB_KAPPA * x_r) + 16) / 116.0 );
+
+  if (y_r > LAB_EPSILON) f_y = pow(y_r, 1.0 / 3.0);
+  else ( f_y = ((LAB_KAPPA * y_r) + 16) / 116.0 );
+
+  if (z_r > LAB_EPSILON) f_z = pow(z_r, 1.0 / 3.0);
+  else ( f_z = ((LAB_KAPPA * z_r) + 16) / 116.0 );
 
   *to_L = (116.0 * f_y) - 16.0;
   *to_a = 500.0 * (f_x - f_y);
@@ -986,53 +1199,30 @@ LAB_to_XYZ (double L,
             double *to_Y,
             double *to_Z)
 {
-
-  const double kappa   = 903.3;//24389.0/27.0;
-  const double epsilon = 0.008856;//216/24389.0;
-  
   double fy, fx, fz, fx_cubed, fy_cubed, fz_cubed;
   double xr, yr, zr;
-  
-/* The constants below hard-code the D50-adapted sRGB ICC profile 
- * reference white, aka the ICC profile D50 illuminant. 
- * 
- * In a properly ICC profile color-managed application, the profile 
- * illuminant values should be retrieved from the image's
- * ICC profile's illuminant.
- * 
- * At present, the ICC profile illuminant is always D50. This might
- * change when the next version of the ICC specs is released.
- * 
- * As encoded in an actual V2 or V4 ICC profile, 
- * the illuminant values are hexadecimal-rounded, as are the following 
- * hard-coded D50 ICC profile illuminant values:
- * 
- */
-  const double X_reference_white = 0.964202880;
-  const double Y_reference_white = 1.000000000;
-  const double Z_reference_white = 0.824905400;
-  
+
   fy = (L + 16.0) / 116.0;
   fy_cubed = fy*fy*fy;
-  
+
   fz = fy - (b / 200.0);
   fz_cubed = fz*fz*fz;
-  
+
   fx = (a / 500.0) + fy;
   fx_cubed = fx*fx*fx;
-  
-  if (fx_cubed > epsilon) xr = fx_cubed;
-  else xr = ((116.0 * fx) - 16) / kappa;
 
-  if ( L > (kappa * epsilon) ) yr = fy_cubed;
-  else yr = (L / kappa);
+  if (fx_cubed > LAB_EPSILON) xr = fx_cubed;
+  else xr = ((116.0 * fx) - 16) / LAB_KAPPA;
 
-  if (fz_cubed > epsilon) zr = fz_cubed;
-  else zr = ( (116.0 * fz) - 16 ) / kappa;
-  
-  *to_X = xr * X_reference_white;
-  *to_Y = yr * Y_reference_white;
-  *to_Z = zr * Z_reference_white;
+  if ( L > (LAB_KAPPA * LAB_EPSILON) ) yr = fy_cubed;
+  else yr = (L / LAB_KAPPA);
+
+  if (fz_cubed > LAB_EPSILON) zr = fz_cubed;
+  else zr = ( (116.0 * fz) - 16 ) / LAB_KAPPA;
+
+  *to_X = xr * D50_WHITE_REF_X;
+  *to_Y = yr * D50_WHITE_REF_Y;
+  *to_Z = zr * D50_WHITE_REF_Z;
 }
 
 static void
