@@ -1,3 +1,4 @@
+#include "config.h"
 #include <stdlib.h>
 #include "babl-internal.h"
 
@@ -8,7 +9,7 @@ int main (void)
   babl_set_extender (babl_extension_quiet_log ());
   babl_fish_stats (stdout);
 
-  babl_destroy ();
+  babl_exit ();
 
   return 0;
 }
