@@ -1,6 +1,7 @@
 /* perform a symmetricality of conversion test on a set of randomized
  * RGBA data */
 
+#include "config.h"
 #include <stdlib.h>
 #include <math.h>
 #include "babl-internal.h"
@@ -28,9 +29,9 @@ int main (void)
   babl_init ();
 
   babl_set_extender (babl_extension_quiet_log ());
-  babl_conversion_each (each_conversion, NULL);
+  babl_conversion_class_for_each (each_conversion, NULL);
 
-  babl_destroy ();
+  babl_exit ();
 
   return !OK;
 }
