@@ -1,6 +1,7 @@
 /* perform a symmetricality of conversion test on a set of randomized
  * RGBA data */
 
+#include "config.h"
 #include <stdlib.h>
 #include <math.h>
 #include "babl-internal.h"
@@ -18,9 +19,9 @@ int main (void)
   babl_init ();
 
   babl_set_extender (babl_extension_quiet_log ());
-  babl_format_each (format_check, (void *) 1);
+  babl_format_class_for_each (format_check, (void *) 1);
 
-  babl_destroy ();
+  babl_exit ();
 
   return 0;
 }
